


resource "kubernetes_ingress" "ingress" {
  for_each = local.ingresses

  metadata {
    name      = each.key
    namespace = lookup(each.value, "namespace", "default")

    annotations = {
      "kubernetes.io/ingress.class"    = "nginx"
      "cert-manager.io/cluster-issuer" = "letsencrypt-production"
    }
  }

  spec {
    dynamic "rule" {
      for_each = each.value["hosts"]

      content {
        host = rule.value.name
        http {
          dynamic "path" {
            for_each = rule.value.rules

            content {
              path = path.value.path
              backend {
                service_name = path.value.service_name
                service_port = path.value.service_port
              }
            }
          }
        }
      }
    }

    dynamic "tls" {
      for_each = lookup(each.value, "tls_secret_name", "") != "" ? [
        [for h in each.value["hosts"] : h.name]
      ] : []

      content {
        secret_name = each.value["tls_secret_name"]
        hosts       = tls.value
      }
    }

  }
}
